## 沪深港股通持股明细

接口：hk_hold，可以通过数据工具调试和查看数据。

描述：获取沪深港股通持股明细，数据来源港交所。

限量：单次最多提取3800条记录，可循环调取，总量不限制

积分：用户积120积分可调取试用，2000积分可正常使用，单位分钟有流控，积分越高流量越大，请自行提高积分，具体请参阅积分获取办法 

说明：交易所于从2024年8月20开始停止发布北向资金数据

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| code | str | N | 交易所代码 |
| ts_code | str | N | TS股票代码 |
| trade_date | str | N | 交易日期 |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |
| exchange | str | N | 类型：SH沪股通（北向）SZ深股通（北向）HK港股通（南向持股） |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| code | str | Y | 原始代码 |
| trade_date | str | Y | 交易日期 |
| ts_code | str | Y | TS代码 |
| name | str | Y | 股票名称 |
| vol | int | Y | 持股数量(股) |
| ratio | float | Y | 持股占比（%），占已发行股份百分比 |
| exchange | str | Y | 类型：SH沪股通SZ深股通HK港股通 |

接口示例

```python
pro = ts.pro_api()

#获取单日全部持股
df = pro.hk_hold(trade_date='20190625')

#获取单日交易所所有持股
df = pro.hk_hold(trade_date='20190625', exchange='SH')
```

数据示例

```python
code  trade_date    ts_code      name        vol  ratio exchange
0     90000   20190625  600000.SH  浦发银行  443245164   1.57       SH
```